#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-1uAv5rz7mDi4nS0fUo7IKS
key:                  hs-bibutils-6.10.0.0-1uAv5rz7mDi4nS0fUo7IKS
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  d493bddb0e6daa3a1f601836f8ab8a7e
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hs-bibutils-6.10.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hs-bibutils
hs-libraries:         HShs-bibutils-6.10.0.0-1uAv5rz7mDi4nS0fUo7IKS
includes:             bibutils.h
depends:              base-4.18.2.1 syb-0.7.4-CWkOfF6Y0mt62kPybHOEB1
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

